@@ -2,7 +2,6 @@
 -- PostgreSQL database dump
 --
 
-
 --
 -- Data for Name: roles; Type: TABLE DATA; Schema: public; Owner: engine
 --
@@ -36,6 +35,12 @@ INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing
 INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children, app_mode) VALUES ('def00011-0000-0000-0000-def000000014', 'BookmarkManager', 'Bookmark Manager', true, 1, false, 255);
 INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children, app_mode) VALUES ('def00011-0000-0000-0000-def000000015', 'EventNotificationManager', 'Event Notification Manager', true, 1, false, 255);
 INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children, app_mode) VALUES ('def00011-0000-0000-0000-def000000016', 'AuditLogManager', 'Audit Log Manager', true, 1, false, 255);
+INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children, app_mode) VALUES ('def00013-0000-0000-0000-def000000013', 'MacPoolAdmin', 'MAC Pool Administrator Role, permission for manipulation with MAC pools', true, 1, true, 1);
+INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children, app_mode) VALUES ('def00014-0000-0000-0000-def000000014', 'MacPoolUser', 'MAC Pool User Role, permission allowing using MAC pools', true, 1, true, 1);
+INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children, app_mode) VALUES ('def00020-0000-0000-0000-abc000000010', 'DiskProfileUser', 'Disk Profile User', true, 2, false, 1);
+INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children, app_mode) VALUES ('def00006-0000-0000-0000-def000000011', 'UserVmRunTimeManager', 'User Role, with permissions for any operations on VMs except snapshot manipulation', true, 2, false, 1);
+INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children, app_mode) VALUES ('def00021-0000-0000-0000-def000000015', 'UserProfileEditor', 'Role that allow users to edit the UserProfile', true, 2, false, 255);
+INSERT INTO roles (id, name, description, is_readonly, role_type, allows_viewing_children, app_mode) VALUES ('def00030-0000-0000-0000-def000000011', 'VmImporterExporter', 'Administrator Role, with permission to import or export Vms', true, 1, true, 1);
 
 
 --
