@@ -2,6 +2,7 @@ package org.ovirt.engine.core.bll;
 
 import javax.inject.Inject;
 
+import org.ovirt.engine.core.bll.context.EngineContext;
 import org.ovirt.engine.core.common.queries.GetEntitiesWithPermittedActionParameters;
 import org.ovirt.engine.core.dao.ClusterDao;
 
@@ -11,8 +12,8 @@ public class GetClustersWithPermittedActionQuery<P extends GetEntitiesWithPermit
     @Inject
     private ClusterDao clusterDao;
 
-    public GetClustersWithPermittedActionQuery(P parameters) {
-        super(parameters);
+    public GetClustersWithPermittedActionQuery(P parameters, EngineContext engineContext) {
+        super(parameters, engineContext);
     }
 
     @Override
