@@ -4,12 +4,14 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 
+import javax.inject.Inject;
+
 import org.ovirt.engine.core.bll.LockMessagesMatchUtil;
 import org.ovirt.engine.core.bll.context.CommandContext;
 import org.ovirt.engine.core.bll.utils.GlusterUtil;
 import org.ovirt.engine.core.common.AuditLogType;
-import org.ovirt.engine.core.common.action.VdcActionType;
-import org.ovirt.engine.core.common.action.VdcReturnValueBase;
+import org.ovirt.engine.core.common.action.ActionReturnValue;
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.action.gluster.CreateGlusterVolumeSnapshotParameters;
 import org.ovirt.engine.core.common.action.gluster.GlusterVolumeGeoRepSessionParameters;
 import org.ovirt.engine.core.common.asynctasks.gluster.GlusterTaskType;
@@ -29,11 +31,17 @@ import org.ovirt.engine.core.common.vdscommands.VDSCommandType;
 import org.ovirt.engine.core.common.vdscommands.VDSReturnValue;
 import org.ovirt.engine.core.common.vdscommands.gluster.CreateGlusterVolumeSnapshotVDSParameters;
 import org.ovirt.engine.core.compat.Guid;
+import org.ovirt.engine.core.dao.gluster.GlusterVolumeDao;
 import org.ovirt.engine.core.utils.lock.EngineLock;
 import org.ovirt.engine.core.utils.transaction.TransactionSupport;
 
 public class CreateGlusterVolumeSnapshotCommand extends GlusterSnapshotCommandBase<CreateGlusterVolumeSnapshotParameters> {
 
+    @Inject
+    private GlusterVolumeDao glusterVolumeDao;
+    @Inject
+    private GlusterUtil glusterUtil;
+
     private GlusterVolumeSnapshotEntity snapshot;
     private boolean force;
     private List<GlusterGeoRepSession> georepSessions;
@@ -74,7 +82,7 @@ public class CreateGlusterVolumeSnapshotCommand extends GlusterSnapshotCommandBa
                     continue;
                 }
 
-                VDS slaveUpServer = getGlusterUtils().getRandomUpServer(slaveVolume.getClusterId());
+                VDS slaveUpServer = glusterUtil.getRandomUpServer(slaveVolume.getClusterId());
                 if (slaveUpServer == null) {
                     handleVdsError(AuditLogType.GLUSTER_VOLUME_SNAPSHOT_CREATE_FAILED,
                             "No up server found in slave cluster of geo-rep session");
@@ -86,10 +94,10 @@ public class CreateGlusterVolumeSnapshotCommand extends GlusterSnapshotCommandBa
                 if (!(session.getStatus() == GeoRepSessionStatus.CREATED
                         || session.getStatus() == GeoRepSessionStatus.PAUSED
                         || session.getStatus() == GeoRepSessionStatus.STOPPED)) {
-                    VdcReturnValueBase sessionPauseRetVal = null;
+                    ActionReturnValue sessionPauseRetVal = null;
                     try (EngineLock lock = acquireEngineLock(slaveVolume.getId(), LockingGroup.GLUSTER_SNAPSHOT)) {
                         sessionPauseRetVal =
-                                runInternalAction(VdcActionType.PauseGlusterVolumeGeoRepSession,
+                                runInternalAction(ActionType.PauseGlusterVolumeGeoRepSession,
                                         new GlusterVolumeGeoRepSessionParameters(getGlusterVolumeId(),
                                                 session.getId()));
                     }
@@ -127,7 +135,7 @@ public class CreateGlusterVolumeSnapshotCommand extends GlusterSnapshotCommandBa
                     glusterVolumeSnapshotDao.save(slaveVolumeSnapshot);
 
                     // check if the snapshot soft limit reached now for the volume and alert
-                    getGlusterUtils().alertVolumeSnapshotLimitsReached(slaveVolume);
+                    glusterUtil.alertVolumeSnapshotLimitsReached(slaveVolume);
                 }
             }
         }
@@ -167,15 +175,15 @@ public class CreateGlusterVolumeSnapshotCommand extends GlusterSnapshotCommandBa
             glusterVolumeSnapshotDao.save(createdSnapshot);
             addCustomValue(GlusterConstants.VOLUME_SNAPSHOT_NAME, createdSnapshot.getSnapshotName());
             // check if the snapshot soft limit reached now for the volume and alert
-            getGlusterUtils().alertVolumeSnapshotLimitsReached(getGlusterVolume());
+            glusterUtil.alertVolumeSnapshotLimitsReached(getGlusterVolume());
         }
 
         // Resume the snapshot paused sessions by engine
         for (GlusterGeoRepSession session : enginePausedSessions) {
             if (session.getStatus() == GeoRepSessionStatus.PAUSED) {
                 try (EngineLock lock = acquireGeoRepSessionLock(session.getId())) {
-                    VdcReturnValueBase sessionResumeRetVal =
-                            runInternalAction(VdcActionType.ResumeGeoRepSession,
+                    ActionReturnValue sessionResumeRetVal =
+                            runInternalAction(ActionType.ResumeGeoRepSession,
                                     new GlusterVolumeGeoRepSessionParameters(volume.getId(), session.getId()));
                     if (!sessionResumeRetVal.getSucceeded()) {
                         handleVdsErrors(AuditLogType.GLUSTER_VOLUME_GEO_REP_RESUME_FAILED,
@@ -207,7 +215,7 @@ public class CreateGlusterVolumeSnapshotCommand extends GlusterSnapshotCommandBa
             return failValidation(EngineMessage.ACTION_TYPE_FAILED_VOLUME_ASYNC_OPERATION_IN_PROGRESS);
         }
 
-        if (!GlusterUtil.getInstance().isVolumeThinlyProvisioned(volume)) {
+        if (!glusterUtil.isVolumeThinlyProvisioned(volume)) {
             return failValidation(EngineMessage.ACTION_TYPE_FAILED_GLUSTER_VOLUME_IS_NOT_THINLY_PROVISIONED);
         }
 
