@@ -72,7 +72,7 @@ public abstract class StorageDomainCommandBase<T extends StorageDomainParameters
     @Inject
     private VmDeviceUtils vmDeviceUtils;
     @Inject
-    private DiskProfileHelper diskProfileHelper;
+    protected DiskProfileHelper diskProfileHelper;
     @Inject
     protected LunHelper lunHelper;
     @Inject
@@ -80,13 +80,13 @@ public abstract class StorageDomainCommandBase<T extends StorageDomainParameters
     @Inject
     private LunDao lunDao;
     @Inject
-    private StorageDomainDao storageDomainDao;
+    protected StorageDomainDao storageDomainDao;
     @Inject
     private StorageDomainDynamicDao storageDomainDynamicDao;
     @Inject
-    private StorageDomainStaticDao storageDomainStaticDao;
+    protected StorageDomainStaticDao storageDomainStaticDao;
     @Inject
-    private VmDao vmDao;
+    protected VmDao vmDao;
 
     @Inject
     protected ImagesHandler imagesHandler;
