@@ -1,10 +1,11 @@
 package org.ovirt.engine.core.bll.exportimport;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import static java.util.Collections.emptyList;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyCollection;
 import static org.mockito.ArgumentMatchers.eq;
@@ -23,13 +24,14 @@ import java.util.Set;
 
 import javax.validation.ConstraintViolation;
 
-import org.junit.Before;
-import org.junit.ClassRule;
-import org.junit.Rule;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.ExtendWith;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
 import org.mockito.Spy;
+import org.mockito.junit.jupiter.MockitoSettings;
+import org.mockito.quality.Strictness;
 import org.ovirt.engine.core.bll.BaseCommandTest;
 import org.ovirt.engine.core.bll.ValidateTestUtils;
 import org.ovirt.engine.core.bll.ValidationResult;
@@ -56,24 +58,21 @@ import org.ovirt.engine.core.common.businessentities.VmDeviceGeneralType;
 import org.ovirt.engine.core.common.businessentities.VmDeviceId;
 import org.ovirt.engine.core.common.businessentities.VmTemplate;
 import org.ovirt.engine.core.common.businessentities.storage.DiskImage;
-import org.ovirt.engine.core.common.config.ConfigValues;
 import org.ovirt.engine.core.common.errors.EngineMessage;
 import org.ovirt.engine.core.common.osinfo.OsRepository;
 import org.ovirt.engine.core.common.utils.Pair;
 import org.ovirt.engine.core.common.utils.ValidationUtils;
 import org.ovirt.engine.core.common.utils.VmDeviceType;
-import org.ovirt.engine.core.common.utils.VmInitToOpenStackMetadataAdapter;
 import org.ovirt.engine.core.compat.Guid;
 import org.ovirt.engine.core.compat.Version;
-import org.ovirt.engine.core.utils.MockConfigRule;
 import org.ovirt.engine.core.utils.RandomUtils;
-import org.ovirt.engine.core.utils.RandomUtilsSeedingRule;
+import org.ovirt.engine.core.utils.RandomUtilsSeedingExtension;
+import org.ovirt.engine.core.vdsbroker.vdsbroker.CloudInitHandler;
 import org.ovirt.engine.core.vdsbroker.vdsbroker.VdsProperties;
 
+@ExtendWith(RandomUtilsSeedingExtension.class)
+@MockitoSettings(strictness = Strictness.LENIENT)
 public class ImportVmCommandTest extends BaseCommandTest {
-    @Rule
-    public RandomUtilsSeedingRule rusr = new RandomUtilsSeedingRule();
-
     @Mock
     private OsRepository osRepository;
 
@@ -97,12 +96,9 @@ public class ImportVmCommandTest extends BaseCommandTest {
     private ImportVmCommand<ImportVmParameters> cmd = new ImportVmCommand<>(createParameters(), null);
 
     @Mock
-    private VmInitToOpenStackMetadataAdapter openStackMetadataAdapter;
+    private CloudInitHandler cloudInitHandler;
 
-    @ClassRule
-    public static MockConfigRule mcr = new MockConfigRule();
-
-    @Before
+    @BeforeEach
     public void setUpOsRepository() {
         final int osId = 0;
 
@@ -112,9 +108,10 @@ public class ImportVmCommandTest extends BaseCommandTest {
         when(osRepository.getGraphicsAndDisplays()).thenReturn(displayTypeMap);
     }
 
-    @Before
+    @BeforeEach
     public void setUp() {
         doReturn(null).when(cmd).getCluster();
+        doReturn(emptyList()).when(cloudInitHandler).validate(any());
     }
 
     @Test
@@ -123,7 +120,6 @@ public class ImportVmCommandTest extends BaseCommandTest {
         doReturn(true).when(cmd).validateImages(any());
         when(cmd.getImportValidator().validateSpaceRequirements(anyCollection())).thenReturn(
                 new ValidationResult(EngineMessage.ACTION_TYPE_FAILED_DISK_SPACE_LOW_ON_STORAGE_DOMAIN));
-        mockMemorySizeConfigValues(Version.getLast());
         ValidateTestUtils.runAndAssertValidateFailure(cmd,
                 EngineMessage.ACTION_TYPE_FAILED_DISK_SPACE_LOW_ON_STORAGE_DOMAIN);
     }
@@ -134,7 +130,6 @@ public class ImportVmCommandTest extends BaseCommandTest {
         doReturn(true).when(cmd).validateImages(any());
         when(cmd.getImportValidator().validateSpaceRequirements(anyCollection())).thenReturn(
                 new ValidationResult(EngineMessage.ACTION_TYPE_FAILED_DISK_SPACE_LOW_ON_STORAGE_DOMAIN));
-        mockMemorySizeConfigValues(Version.getLast());
         ValidateTestUtils.runAndAssertValidateFailure(cmd,
                 EngineMessage.ACTION_TYPE_FAILED_DISK_SPACE_LOW_ON_STORAGE_DOMAIN);
     }
@@ -178,7 +173,6 @@ public class ImportVmCommandTest extends BaseCommandTest {
 
         addBalloonToVm(cmd.getVmFromExportDomain(null));
         when(osRepository.isBalloonEnabled(cmd.getParameters().getVm().getVmOsId(), cmd.getCluster().getCompatibilityVersion())).thenReturn(false);
-        mockMemorySizeConfigValues(cmd.getCluster().getCompatibilityVersion());
 
         assertFalse(cmd.validate());
         assertTrue(cmd.getReturnValue()
@@ -192,7 +186,6 @@ public class ImportVmCommandTest extends BaseCommandTest {
 
         addSoundDeviceToVm(cmd.getVmFromExportDomain(null));
         when(osRepository.isSoundDeviceEnabled(cmd.getParameters().getVm().getVmOsId(), cmd.getCluster().getCompatibilityVersion())).thenReturn(false);
-        mockMemorySizeConfigValues(cmd.getCluster().getCompatibilityVersion());
 
         assertFalse(cmd.validate());
         assertTrue(cmd.getReturnValue()
@@ -228,7 +221,6 @@ public class ImportVmCommandTest extends BaseCommandTest {
         doReturn(true).when(cmd).validateImages(any());
         when(cmd.getImportValidator().validateSpaceRequirements(anyCollection()))
                 .thenReturn(new ValidationResult(EngineMessage.ACTION_TYPE_FAILED_DISK_SPACE_LOW_ON_STORAGE_DOMAIN));
-        mockMemorySizeConfigValues(Version.getLast());
         ValidateTestUtils.runAndAssertValidateFailure(cmd,
                 EngineMessage.ACTION_TYPE_FAILED_DISK_SPACE_LOW_ON_STORAGE_DOMAIN);
     }
@@ -353,7 +345,7 @@ public class ImportVmCommandTest extends BaseCommandTest {
     }
 
     @Test
-    public void testDoNotValidateNameSizeImport() {
+    public void testValidateNameSizeImport() {
         checkVmName(false, RandomUtils.instance().nextPropertyString(300));
     }
 
@@ -363,7 +355,7 @@ public class ImportVmCommandTest extends BaseCommandTest {
     }
 
     @Test
-    public void testDoNotValidateNameSpecialCharsImport() {
+    public void testValidateNameSpecialCharsImport() {
         checkVmName(false, "vm_#$@%$#@@");
     }
 
@@ -374,7 +366,7 @@ public class ImportVmCommandTest extends BaseCommandTest {
         Set<ConstraintViolation<ImportVmParameters>> validate =
                 ValidationUtils.getValidator().validate(cmd.getParameters(),
                         cmd.getValidationGroups().toArray(new Class<?>[0]));
-        assertEquals(validate.isEmpty(), !isImportAsNewEntity);
+        assertFalse(validate.isEmpty());
     }
 
     /**
@@ -420,13 +412,12 @@ public class ImportVmCommandTest extends BaseCommandTest {
         cmd.generateNewDiskId(diskList, disk);
         cmd.updateManagedDeviceMap(disk, managedDevices);
         Guid oldDiskId = cmd.newDiskIdForDisk.get(disk.getId()).getId();
-        assertEquals("The old disk id should be similar to the value at the newDiskIdForDisk.",
-                beforeOldDiskId,
-                oldDiskId);
-        assertNotNull("The manged device should return the disk device by the new key",
-                managedDevices.get(disk.getId()));
-        assertNull("The manged device should not return the disk device by the old key",
-                managedDevices.get(beforeOldDiskId));
+        assertEquals(beforeOldDiskId, oldDiskId,
+                "The old disk id should be similar to the value at the newDiskIdForDisk.");
+        assertNotNull(managedDevices.get(disk.getId()),
+                "The manged device should return the disk device by the new key");
+        assertNull(managedDevices.get(beforeOldDiskId),
+                "The manged device should not return the disk device by the old key");
     }
 
     /* Tests for alias generation in addVmImagesAndSnapshots() */
@@ -444,7 +435,7 @@ public class ImportVmCommandTest extends BaseCommandTest {
         doNothing().when(cmd).saveDiskVmElement(any(), any(), any());
         doReturn(new Snapshot()).when(cmd).addActiveSnapshot(any());
         cmd.addVmImagesAndSnapshots();
-        assertEquals("Disk alias not generated", "testVm_Disk1", collapsedDisk.getDiskAlias());
+        assertEquals("testVm_Disk1", collapsedDisk.getDiskAlias(), "Disk alias not generated");
     }
 
     /* Test import images with empty Guid is failing */
@@ -499,7 +490,7 @@ public class ImportVmCommandTest extends BaseCommandTest {
         doNothing().when(cmd).saveDiskVmElement(any(), any(), any());
 
         cmd.addVmImagesAndSnapshots();
-        assertEquals("Disk alias not generated", "testVm_Disk1", activeDisk.getDiskAlias());
+        assertEquals("testVm_Disk1", activeDisk.getDiskAlias(), "Disk alias not generated");
     }
 
     @Test
@@ -519,12 +510,6 @@ public class ImportVmCommandTest extends BaseCommandTest {
         doReturn(new Snapshot()).when(cmd).addActiveSnapshot(any());
 
         cmd.addVmImagesAndSnapshots();
-        assertEquals("Disk alias not generated", "testVm_Disk1", activeDisk.getDiskAlias());
-    }
-
-    private void mockMemorySizeConfigValues(Version version) {
-        mcr.mockConfigValue(ConfigValues.VM32BitMaxMemorySizeInMB, version, 20480);
-        mcr.mockConfigValue(ConfigValues.VM64BitMaxMemorySizeInMB, version, 4194304);
-        mcr.mockConfigValue(ConfigValues.VMPpc64BitMaxMemorySizeInMB, version, 1048576);
+        assertEquals("testVm_Disk1", activeDisk.getDiskAlias(), "Disk alias not generated");
     }
 }
