@@ -94,7 +94,7 @@ public class VmManagementParametersBase extends VmOperationParameterBase
     @EditableDeviceOnVmStatusField(generalType = VmDeviceGeneralType.WATCHDOG, type = VmDeviceType.WATCHDOG)
     private Optional<VmWatchdog> watchdog = new Optional<>();
 
-    @EditableDeviceOnVmStatusField(generalType = VmDeviceGeneralType.RNG, type = VmDeviceType.VIRTIO)
+    @EditableDeviceOnVmStatusField(generalType = VmDeviceGeneralType.RNG, type = VmDeviceType.VIRTIO, name="rng")
     private Optional<VmRngDevice> rngDevice = new Optional<>();
 
     /*
@@ -103,7 +103,7 @@ public class VmManagementParametersBase extends VmOperationParameterBase
      * for add vm legacy logic will be used: create device for desktop type
      * for update the current configuration will remain
      */
-    @EditableDeviceOnVmStatusField(generalType = VmDeviceGeneralType.SOUND, type = VmDeviceType.UNKNOWN, isReadOnly = true)
+    @EditableDeviceOnVmStatusField(generalType = VmDeviceGeneralType.SOUND, type = VmDeviceType.UNKNOWN, name="sound", isReadOnly = true)
     private Boolean soundDeviceEnabled;
 
     /*
@@ -119,7 +119,7 @@ public class VmManagementParametersBase extends VmOperationParameterBase
      * - Add VM - defaulted to true for cluster >= 3.3
      * - Update VM - preserve current configuration
      */
-    @EditableDeviceOnVmStatusField(generalType = VmDeviceGeneralType.CONTROLLER, type = VmDeviceType.VIRTIOSCSI)
+    @EditableDeviceOnVmStatusField(generalType = VmDeviceGeneralType.CONTROLLER, type = VmDeviceType.VIRTIOSCSI, name="virtioscsi")
     private Boolean virtioScsiEnabled;
 
     /**
