@@ -34,7 +34,7 @@ public class ReflectionHelper {
         R ret = null;
         try {
             ret = clz.newInstance();
-        } catch (Exception e) {
+        } catch (Exception ignore) {
         }
         return ret;
     }
@@ -93,6 +93,12 @@ public class ReflectionHelper {
         return method != null ? method : getMethod(o, IS_ROOT + capitalizedName);
     }
 
+    public static Method getSetter(Object o, String name) {
+        String capitalizedName = capitalize(name);
+        Method method = getMethod(o, SET_ROOT + capitalizedName);
+        return method;
+    }
+
     public static Class<?> getReturnType(Object o, String name) {
         Method getter = getGetter(o, name);
         return getter.getReturnType();
