@@ -1,10 +1,10 @@
 package org.ovirt.engine.core.utils;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotSame;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.Arrays;
 import java.util.HashSet;
@@ -13,8 +13,8 @@ import java.util.Set;
 import java.util.prefs.BackingStoreException;
 import java.util.prefs.Preferences;
 
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.ovirt.engine.core.common.businessentities.ChipsetType;
 import org.ovirt.engine.core.common.businessentities.DisplayType;
 import org.ovirt.engine.core.common.businessentities.GraphicsType;
@@ -36,11 +36,11 @@ public class OsRepositoryImplTest {
     public static final String MAX_PCI_DEVICES = "26";
     public static final String PATH_TO_SYSPREP = "/path/to/sysprep";
     public static final String SOME_PRODUCT_KEY = "some-product-key";
-    public static final String SOUND_DEVICE = "ac97";
+    public static final String SOUND_DEVICE = "ac97,q35/ich9";
     public static final String CD_INTERFACE = "ide,q35/sata";
 
-    @BeforeClass
-    public static void setUp() throws Exception {
+    @BeforeAll
+    public static void setUp() {
         preferences = new MapBackedPreferences(preferences, "");
         preferences.node("/os/rhel7/id").put("value", "777");
         preferences.node("/os/rhel7/name").put("value", "RHEL 7");
@@ -50,10 +50,10 @@ public class OsRepositoryImplTest {
         preferences.node("/os/rhel7/devices/disk/hotpluggableInterfaces").put("value", DISK_HOTPLUGGABLE_INTERFACES);
         preferences.node("/os/rhel7/devices/watchdog/models").put("value", WATCH_DOG_MODELS);
         preferences.node("/os/rhel7/devices/maxPciDevices").put("value", MAX_PCI_DEVICES);
-        preferences.node("/os/rhel7/resources/minimum/ram").put("value", "1024");
-        preferences.node("/os/rhel7/resources/minimum/ram").put("value.3.6", "512");
+        preferences.node("/os/rhel7/resources/minimum/ram").put("value", "2048");
+        preferences.node("/os/rhel7/resources/minimum/ram").put("value.4.1", "1024");
         preferences.node("/os/rhel7/resources/maximum/ram").put("value", "2048");
-        preferences.node("/os/rhel7/devices/display/protocols").put("value", "VNC/cirrus,SPICE/qxl");
+        preferences.node("/os/rhel7/devices/display/protocols").put("value", "VNC/vga,SPICE/qxl");
         preferences.node("/os/rhel7/devices/balloon/enabled").put("value", "true");
         preferences.node("/os/rhel7/devices/audio/enabled").put("value", "true");
         preferences.node("/os/rhel7/devices/floppy/support").put("value", "true");
@@ -75,10 +75,10 @@ public class OsRepositoryImplTest {
         preferences.node("/os/windows_8/sysprepFileName").put("value", UNATTEND_XML);
         preferences.node("/os/windows_xp/id").put("value", "1");
         preferences.node("/os/windows_xp/sysprepFileName").put("value", SYSPREP_INF);
-        preferences.node("/os/rhel7/devices/usb/controller").put("value", "nec-xhci");
+        preferences.node("/os/rhel7/devices/usb/controller").put("value", "nec-xhci,q35/qemu-xhci");
         preferences.node("/os/rhel6/id").put("value", "999");
         preferences.node("/os/rhel6/devices/usb/controller").put("value", "nec-xhci");
-        preferences.node("/os/rhel6/devices/usb/controller").put("value.4.0", "none");
+        preferences.node("/os/rhel6/devices/usb/controller").put("value.4.1", "none");
         OsRepositoryImpl.INSTANCE.init(preferences);
     }
 
@@ -90,52 +90,52 @@ public class OsRepositoryImplTest {
     }
 
     @Test
-    public void testGetOsIds() throws Exception {
+    public void testGetOsIds() {
         assertTrue(OsRepositoryImpl.INSTANCE.getOsIds().contains(777));
     }
 
     @Test
-    public void testGetOsIdByUniqueName() throws Exception {
+    public void testGetOsIdByUniqueName() {
         assertEquals(777, OsRepositoryImpl.INSTANCE.getOsIdByUniqueName("rhel7"));
     }
 
     @Test
-    public void testGetOsNames() throws Exception {
+    public void testGetOsNames() {
         assertEquals("RHEL 7", OsRepositoryImpl.INSTANCE.getOsNames().get(777));
     }
 
     @Test
-    public void testGetOsName() throws Exception {
+    public void testGetOsName() {
         assertEquals("RHEL 7", OsRepositoryImpl.INSTANCE.getOsName(777));
     }
 
     @Test
-    public void testGetOsFamily() throws Exception {
+    public void testGetOsFamily() {
         assertEquals("linux", OsRepositoryImpl.INSTANCE.getOsFamily(777));
     }
 
     @Test
-    public void testGetLinuxOSs() throws Exception {
+    public void testGetLinuxOSs() {
         assertTrue(OsRepositoryImpl.INSTANCE.getLinuxOss().contains(777));
     }
 
     @Test
-    public void testGet64bitOss() throws Exception {
+    public void testGet64bitOss() {
         assertEquals(2, OsRepositoryImpl.INSTANCE.get64bitOss().size());
     }
 
     @Test
-    public void testGetWindowsOss() throws Exception {
+    public void testGetWindowsOss() {
         assertEquals(0, OsRepositoryImpl.INSTANCE.getWindowsOss().size());
     }
 
     @Test
-    public void testIsWindows() throws Exception {
+    public void testIsWindows() {
         assertFalse(OsRepositoryImpl.INSTANCE.isWindows(777));
     }
 
     @Test
-    public void testGetNetworkDevices() throws Exception {
+    public void testGetNetworkDevices() {
         List<String> networkDevices = OsRepositoryImpl.INSTANCE.getNetworkDevices(777, null);
         assertEquals(2, networkDevices.size());
         for (String device : NETWORK_DEVICES.split(",")) {
@@ -144,7 +144,7 @@ public class OsRepositoryImplTest {
     }
 
     @Test
-    public void testGetDiskHotpluggableInterfaces() throws Exception {
+    public void testGetDiskHotpluggableInterfaces() {
         Set<String> diskHotpluggableInterfaces = OsRepositoryImpl.INSTANCE.getDiskHotpluggableInterfaces(777, null);
         assertEquals(2, diskHotpluggableInterfaces.size());
         for (String diskHotpluggableInterface : DISK_HOTPLUGGABLE_INTERFACES.split(",")) {
@@ -153,7 +153,7 @@ public class OsRepositoryImplTest {
     }
 
     @Test
-    public void testGetWatchDogModels() throws Exception {
+    public void testGetWatchDogModels() {
         List<String> watchDogModels = OsRepositoryImpl.INSTANCE.getWatchDogModels(777, null);
         assertEquals(2, watchDogModels.size());
         for (String model : WATCH_DOG_MODELS.split(",")) {
@@ -162,87 +162,92 @@ public class OsRepositoryImplTest {
     }
 
     @Test
-    public void testIsLinux() throws Exception {
+    public void testIsLinux() {
         assertTrue(OsRepositoryImpl.INSTANCE.isLinux(777));
     }
 
     @Test
-    public void testGetMinimumRam() throws Exception {
-        assertEquals(1024, OsRepositoryImpl.INSTANCE.getMinimumRam(777, null));
+    public void testGetMinimumRam() {
+        assertEquals(2048, OsRepositoryImpl.INSTANCE.getMinimumRam(777, null));
     }
 
     @Test
-    public void testGetMaximumRam() throws Exception {
+    public void testGetMaximumRam() {
         assertEquals(2048, OsRepositoryImpl.INSTANCE.getMaximumRam(777, null));
     }
 
     @Test
-    public void testDisplayTypes() throws Exception {
+    public void testDisplayTypes() {
         List<Pair<GraphicsType, DisplayType>> supportedGraphicsAndDisplays = OsRepositoryImpl.INSTANCE.getGraphicsAndDisplays().get(777).get(null);
 
         boolean isSizeCorrect = supportedGraphicsAndDisplays.size() == 2;
         boolean containsSameElements = new HashSet<>(supportedGraphicsAndDisplays)
                 .equals(new HashSet<>(Arrays.asList(
                         new Pair<>(GraphicsType.SPICE, DisplayType.qxl),
-                        new Pair<>(GraphicsType.VNC, DisplayType.cirrus))));
+                        new Pair<>(GraphicsType.VNC, DisplayType.vga))));
 
         assertTrue(isSizeCorrect);
         assertTrue(containsSameElements);
     }
 
     @Test
-    public void testFloppySupport() throws Exception {
+    public void testFloppySupport() {
         assertTrue(OsRepositoryImpl.INSTANCE.isFloppySupported(777, null));
     }
 
     @Test
-    public void testIsBalloonEnabled() throws Exception {
+    public void testIsBalloonEnabled() {
         assertTrue(OsRepositoryImpl.INSTANCE.isBalloonEnabled(777, null));
         assertTrue(OsRepositoryImpl.INSTANCE.getBalloonSupportMap().get(777).get(null));
     }
 
     @Test
-    public void testIsSoundDeviceEnabled() throws Exception {
+    public void testIsSoundDeviceEnabled() {
         assertTrue(OsRepositoryImpl.INSTANCE.isSoundDeviceEnabled(777, null));
         assertTrue(OsRepositoryImpl.INSTANCE.getSoundDeviceSupportMap().get(777).get(null));
     }
 
     @Test
-    public void testGetMaxPciDevices() throws Exception {
+    public void testGetMaxPciDevices() {
         assertEquals(26, OsRepositoryImpl.INSTANCE.getMaxPciDevices(777, null));
     }
 
     @Test
-    public void testGetSysprepPath() throws Exception {
+    public void testGetSysprepPath() {
         assertEquals(PATH_TO_SYSPREP, OsRepositoryImpl.INSTANCE.getSysprepPath(777, null));
     }
 
     @Test
-    public void testGetSysprepFileName() throws Exception {
+    public void testGetSysprepFileName() {
         assertEquals(SYSPREP_INF, OsRepositoryImpl.INSTANCE.getSysprepFileName(1, null));
         assertEquals(UNATTEND_XML, OsRepositoryImpl.INSTANCE.getSysprepFileName(11, null));
         assertEquals(UNATTEND_XML, OsRepositoryImpl.INSTANCE.getSysprepFileName(20, null));
     }
 
     @Test
-    public void testGetProductKey() throws Exception {
+    public void testGetProductKey() {
         assertEquals(SOME_PRODUCT_KEY, OsRepositoryImpl.INSTANCE.getProductKey(777, null));
     }
 
     @Test
-    public void testGetSoundDevice() throws Exception {
-        assertEquals(SOUND_DEVICE, OsRepositoryImpl.INSTANCE.getSoundDevice(777, null));
+    public void testGetSoundDevice() {
+        assertEquals("ac97", OsRepositoryImpl.INSTANCE.getSoundDevice(777, null, ChipsetType.I440FX));
     }
 
     @Test
-    public void testGetCdInterface() throws Exception {
+    public void testGetSoundDeviceQ35() {
+        assertEquals("ich9", OsRepositoryImpl.INSTANCE.getSoundDevice(777, null, ChipsetType.Q35));
+    }
+
+    @Test
+    public void testGetCdInterface() {
         assertEquals("ide", OsRepositoryImpl.INSTANCE.getCdInterface(777, null, null));
         assertEquals("ide", OsRepositoryImpl.INSTANCE.getCdInterface(777, null, ChipsetType.I440FX));
         assertEquals("sata", OsRepositoryImpl.INSTANCE.getCdInterface(777, null, ChipsetType.Q35));
     }
 
     @Test
-    public void testIsTimezoneValueInteger() throws Exception {
+    public void testIsTimezoneValueInteger() {
         assertFalse(OsRepositoryImpl.INSTANCE.isTimezoneValueInteger(777, null));
     }
 
@@ -258,18 +263,18 @@ public class OsRepositoryImplTest {
 
     @Test
     public void testVersionedValue() {
-        assertEquals(1024, OsRepositoryImpl.INSTANCE.getMinimumRam(777, null));
-        assertEquals(512, OsRepositoryImpl.INSTANCE.getMinimumRam(777, Version.v3_6));
+        assertEquals(2048, OsRepositoryImpl.INSTANCE.getMinimumRam(777, null));
+        assertEquals(1024, OsRepositoryImpl.INSTANCE.getMinimumRam(777, Version.v4_1));
     }
 
     @Test
     public void testDerivedVersionedValue() {
-        assertEquals(512, OsRepositoryImpl.INSTANCE.getMinimumRam(888, Version.v3_6));
+        assertEquals(1024, OsRepositoryImpl.INSTANCE.getMinimumRam(888, Version.v4_1));
     }
 
     @Test
     public void testdefaultVersionedValue() {
-        assertEquals(1024, OsRepositoryImpl.INSTANCE.getMinimumRam(888, Version.v4_0));
+        assertEquals(2048, OsRepositoryImpl.INSTANCE.getMinimumRam(888, Version.v4_3));
     }
 
     @Test
@@ -279,13 +284,17 @@ public class OsRepositoryImplTest {
     }
 
     @Test
-    public void testHyperVLinux() throws Exception {
-        assertFalse(OsRepositoryImpl.INSTANCE.isHypervEnabled(OsRepositoryImpl.INSTANCE.getOsIdByUniqueName("rhel7"), Version.v3_6));
+    public void testHyperVLinux() {
+        assertFalse(OsRepositoryImpl.INSTANCE.isHypervEnabled(
+                OsRepositoryImpl.INSTANCE.getOsIdByUniqueName("rhel7"),
+                Version.v4_1));
     }
 
     @Test
-    public void testHyperVWindows() throws Exception {
-        assertTrue(OsRepositoryImpl.INSTANCE.isHypervEnabled(OsRepositoryImpl.INSTANCE.getOsIdByUniqueName("windows_7"), Version.v3_6));
+    public void testHyperVWindows() {
+        assertTrue(OsRepositoryImpl.INSTANCE.isHypervEnabled(
+                OsRepositoryImpl.INSTANCE.getOsIdByUniqueName("windows_7"),
+                Version.v4_1));
     }
 
     @Test
@@ -325,15 +334,26 @@ public class OsRepositoryImplTest {
     public void testExistingUsbControllerModelWithoutVersion() {
         final UsbControllerModel model = OsRepositoryImpl.INSTANCE.getOsUsbControllerModel(
                 OsRepositoryImpl.INSTANCE.getOsIdByUniqueName("rhel7"),
-                null);
+                null,
+                ChipsetType.I440FX);
         assertEquals(UsbControllerModel.NEC_XHCI, model);
     }
 
+    @Test
+    public void testExistingUsbControllerModelWithChipset() {
+        final UsbControllerModel model = OsRepositoryImpl.INSTANCE.getOsUsbControllerModel(
+                OsRepositoryImpl.INSTANCE.getOsIdByUniqueName("rhel7"),
+                null,
+                ChipsetType.Q35);
+        assertEquals(UsbControllerModel.QEMU_XHCI, model);
+    }
+
     @Test
     public void testExistingUsbControllerModelWithVersion() {
         final UsbControllerModel model = OsRepositoryImpl.INSTANCE.getOsUsbControllerModel(
                 OsRepositoryImpl.INSTANCE.getOsIdByUniqueName("rhel6"),
-                Version.v4_0);
+                Version.v4_1,
+                ChipsetType.I440FX);
         assertEquals(UsbControllerModel.NONE, model);
     }
 
@@ -341,7 +361,8 @@ public class OsRepositoryImplTest {
     public void testExistingUsbControllerModelWithNonExistingVersion() {
         final UsbControllerModel model = OsRepositoryImpl.INSTANCE.getOsUsbControllerModel(
                 OsRepositoryImpl.INSTANCE.getOsIdByUniqueName("rhel6"),
-                Version.v4_1);
+                Version.v4_2,
+                ChipsetType.I440FX);
         assertEquals(UsbControllerModel.NEC_XHCI, model);
     }
 
@@ -349,7 +370,8 @@ public class OsRepositoryImplTest {
     public void testNonExistingUsbControllerModel() {
         final UsbControllerModel model = OsRepositoryImpl.INSTANCE.getOsUsbControllerModel(
                 OsRepositoryImpl.INSTANCE.getOsIdByUniqueName("windows_8"),
-                null);
+                null,
+                ChipsetType.I440FX);
         assertNull(model);
     }
 }
