@@ -1,18 +1,18 @@
 package org.ovirt.engine.core.vdsbroker.gluster;
 
 import org.ovirt.engine.core.common.vdscommands.VdsIdVDSCommandParametersBase;
-import org.ovirt.engine.core.vdsbroker.vdsbroker.StatusForXmlRpc;
+import org.ovirt.engine.core.vdsbroker.vdsbroker.Status;
 
 public class GetGlusterVolumeOptionsInfoVDSCommand<P extends VdsIdVDSCommandParametersBase> extends AbstractGlusterBrokerCommand<P> {
-    private GlusterVolumeOptionsInfoReturnForXmlRpc result;
+    private GlusterVolumeOptionsInfoReturn result;
 
     public GetGlusterVolumeOptionsInfoVDSCommand(P parameters) {
         super(parameters);
     }
 
     @Override
-    protected StatusForXmlRpc getReturnStatus() {
-        return result.mStatus;
+    protected Status getReturnStatus() {
+        return result.getStatus();
     }
 
     @Override
