@@ -129,8 +129,7 @@ public class VmAnalyzer {
     }
 
     /**
-     * update the internals of this VM
-     * against its match
+     * update the internals of this VM against its match
      * this method shouldn't throw exception but fail in isolated way.
      * TODO consider throwing a checked exception or catching one inside
      */
@@ -155,8 +154,7 @@ public class VmAnalyzer {
             return;
         }
 
-        proceedWatchdogEvents();
-        proceedVmReportedOnTheSameHost();
+        proceedVmReportedOnExpectedHost();
     }
 
     private boolean isVmStoppedBeingReported() {
@@ -239,6 +237,13 @@ public class VmAnalyzer {
                 return;
             }
 
+            if (dbVm.getRunOnVds() != null // The VM is supposedly running elsewhere
+                    && dbVm.getStatus() != VMStatus.Unknown
+                    && !isVmMigratingToThisVds()) {
+                destroyVm();
+                return;
+            }
+
             // otherwise continue with default processing
             break;
 
@@ -392,7 +397,7 @@ public class VmAnalyzer {
         auditLog(logable, type);
     }
 
-    private void clearVm(VmExitStatus exitStatus, String exitMessage, VmExitReason vmExistReason) {
+    private void clearVm(VmExitStatus exitStatus, String exitMessage, VmExitReason vmExitReason) {
         if (dbVm.getStatus() != VMStatus.MigratingFrom) {
             if (dbVm.getStatus() != VMStatus.Suspended) {
                 // if the VM is set to down then the actual exit fields were set and we don't want to
@@ -402,7 +407,7 @@ public class VmAnalyzer {
                         VMStatus.Down,
                         alreadyDown ? dbVm.getExitStatus() : exitStatus,
                         alreadyDown ? dbVm.getExitMessage() : exitMessage,
-                        alreadyDown ? dbVm.getExitReason() : vmExistReason);
+                        alreadyDown ? dbVm.getExitReason() : vmExitReason);
             }
             saveDynamic(dbVm);
             resetVmStatistics();
@@ -472,8 +477,13 @@ public class VmAnalyzer {
     }
 
     private void proceedWatchdogEvents() {
-        VmDynamic vmDynamic = vdsmVm.getVmDynamic();
-        if (isNewWatchdogEvent(vmDynamic, dbVm)) {
+        Long lastWatchdogEvent = vdsmVm.getVmDynamic().getLastWatchdogEvent();
+        if (lastWatchdogEvent == null) {
+            // no watchdog event is reported
+            return;
+        }
+        if (dbVm.getLastWatchdogEvent() == null || dbVm.getLastWatchdogEvent() < lastWatchdogEvent) {
+            VmDynamic vmDynamic = vdsmVm.getVmDynamic();
             AuditLogableBase auditLogable = Injector.injectMembers(new AuditLogableBase());
             auditLogable.setVmId(vmDynamic.getId());
             auditLogable.addCustomValue("wdaction", vmDynamic.getLastWatchdogAction());
@@ -483,12 +493,6 @@ public class VmAnalyzer {
         }
     }
 
-    protected static boolean isNewWatchdogEvent(VmDynamic vmDynamic, VmDynamic vmTo) {
-        Long lastWatchdogEvent = vmDynamic.getLastWatchdogEvent();
-        return lastWatchdogEvent != null
-                && (vmTo.getLastWatchdogEvent() == null || vmTo.getLastWatchdogEvent() < lastWatchdogEvent);
-    }
-
     private void proceedBalloonCheck() {
         VmBalloonInfo balloonInfo = vdsmVm.getVmBalloonInfo();
         if (balloonInfo == null) {
@@ -552,13 +556,15 @@ public class VmAnalyzer {
     }
 
 
-    private void proceedVmReportedOnTheSameHost() {
+    private void proceedVmReportedOnExpectedHost() {
         if (vdsmVm.getVmDynamic().getStatus() == VMStatus.MigratingTo) {
             log.info("VM '{}' is migrating to VDS '{}'({}) ignoring it in the refresh until migration is done",
                     vdsmVm.getVmDynamic().getId(), vdsManager.getVdsId(), vdsManager.getVdsName());
             return;
         }
 
+        proceedWatchdogEvents();
+
         VmDynamic vdsmVmDynamic = vdsmVm.getVmDynamic();
 
         if (!Objects.equals(vdsmVmDynamic.getClientIp(), dbVm.getClientIp())) {
@@ -618,7 +624,7 @@ public class VmAnalyzer {
         if (vdsmVmDynamic.getStatus() == VMStatus.Paused) {
             if (vdsmVmDynamic.getPauseStatus() == VmPauseStatus.POSTCOPY) {
                 handOverVm();
-                // no need to do anything else besides the hand-over
+                // no need to do anything else besides handing over the VM
                 return;
             }
 
@@ -899,9 +905,11 @@ public class VmAnalyzer {
                 vdsmVm.getVmStatistics(),
                 getVmManager().getNumOfCpus(),
                 updateMigrationProgress);
-        if (dbVm.getBootTime() != null) {
+        // Apparently, users want to see the time that the guest is running rather than that of the VM and therefore
+        // it needs to be cleared when the guest reboots. So let's keep using the value that is reported by VDSM.
+        /*if (dbVm.getBootTime() != null) {
             statistics.setElapsedTime((System.currentTimeMillis() - dbVm.getBootTime().getTime()  - dbVm.getDowntime()) / 1000.0);
-        }
+        }*/
     }
 
     private void updateDiskImageDynamics() {
