@@ -2,6 +2,7 @@ package org.ovirt.engine.ui.uicommonweb.models.storage;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Objects;
 
 import org.ovirt.engine.core.common.businessentities.NfsVersion;
 import org.ovirt.engine.core.common.businessentities.StorageDomain;
@@ -23,7 +24,6 @@ import org.ovirt.engine.ui.uicompat.ConstantsManager;
 import org.ovirt.engine.ui.uicompat.Event;
 import org.ovirt.engine.ui.uicompat.EventArgs;
 import org.ovirt.engine.ui.uicompat.EventDefinition;
-import org.ovirt.engine.ui.uicompat.IEventListener;
 import org.ovirt.engine.ui.uicompat.UIConstants;
 
 public class NfsStorageModel extends FileStorageModel {
@@ -33,7 +33,7 @@ public class NfsStorageModel extends FileStorageModel {
     //timeo nfs option max value
     private static final short TIMEOUT_MAX = 6000;
 
-    public static final EventDefinition pathChangedEventDefinition;
+    public static final EventDefinition pathChangedEventDefinition = new EventDefinition("PathChanged", NfsStorageModel.class); //$NON-NLS-1$
     private Event<EventArgs> pathChangedEvent;
 
     public Event<EventArgs> getPathChangedEvent() {
@@ -86,17 +86,8 @@ public class NfsStorageModel extends FileStorageModel {
         getRetransmissions().setEntity(connection.getNfsRetrans());
         getTimeout().setEntity(connection.getNfsTimeo());
         getMountOptions().setEntity(connection.getMountOptions());
-        for (EntityModel<NfsVersion> item : getVersion().getItems()) {
-            EntityModel itemModel = item;
-            boolean noNfsVersion = itemModel.getEntity() == null && connection.getNfsVersion() == null;
-            boolean foundNfsVersion = itemModel.getEntity() != null &&
-                    itemModel.getEntity().equals(connection.getNfsVersion());
-
-            if (noNfsVersion || foundNfsVersion) {
-                getVersion().setSelectedItem(item);
-                break;
-            }
-        }
+        getVersion().getItems().stream().filter(i -> Objects.equals(i.getEntity(), connection.getNfsVersion()))
+                .findFirst().ifPresent(i -> getVersion().setSelectedItem(i));
     }
 
     private ListModel<EntityModel<NfsVersion>> version;
@@ -139,23 +130,18 @@ public class NfsStorageModel extends FileStorageModel {
         mountOptions = value;
     }
 
-    static {
-
-        pathChangedEventDefinition = new EventDefinition("PathChanged", NfsStorageModel.class); //$NON-NLS-1$
-    }
-
     public NfsStorageModel() {
         setPathChangedEvent(new Event<>(pathChangedEventDefinition));
 
         setUpdateCommand(new UICommand("Update", this)); //$NON-NLS-1$
 
-        setPath(new EntityModel<String>());
+        setPath(new EntityModel<>());
         getPath().getEntityChangedEvent().addListener(this);
 
         UIConstants constants = ConstantsManager.getInstance().getConstants();
 
         // Initialize version list.
-        setVersion(new ListModel<EntityModel<NfsVersion>>());
+        setVersion(new ListModel<>());
 
         List<EntityModel<NfsVersion>> versionItems = new ArrayList<>();
         // Items are shown in the UI in the order added; Auto negotiate is the default
@@ -163,13 +149,14 @@ public class NfsStorageModel extends FileStorageModel {
         versionItems.add(new EntityModel<>(constants.nfsVersionAutoNegotiate(), NfsVersion.AUTO));
         versionItems.add(new EntityModel<>(constants.nfsVersion3(), NfsVersion.V3));
         versionItems.add(new EntityModel<>(constants.nfsVersion4(), NfsVersion.V4));
+        versionItems.add(new EntityModel<>(constants.nfsVersion40(), NfsVersion.V4_0));
         versionItems.add(new EntityModel<>(constants.nfsVersion41(), NfsVersion.V4_1));
         versionItems.add(new EntityModel<>(constants.nfsVersion42(), NfsVersion.V4_2));
         getVersion().setItems(versionItems);
 
-        setRetransmissions(new EntityModel<Short>());
-        setTimeout(new EntityModel<Short>());
-        setMountOptions(new EntityModel<String>());
+        setRetransmissions(new EntityModel<>());
+        setTimeout(new EntityModel<>());
+        setMountOptions(new EntityModel<>());
 
     }
 
@@ -225,13 +212,7 @@ public class NfsStorageModel extends FileStorageModel {
         }
 
         ListModel<StoragePool> dataCenter = getContainer().getDataCenter();
-        dataCenter.getSelectedItemChangedEvent().addListener(new IEventListener<EventArgs>() {
-            @Override
-            public void eventRaised(Event<? extends EventArgs> ev, Object sender, EventArgs args) {
-
-                containerDataCenterChanged();
-            }
-        });
+        dataCenter.getSelectedItemChangedEvent().addListener((ev, sender, args) -> containerDataCenterChanged());
 
         // Call handler if there some data center is already selected.
         if (dataCenter.getSelectedItem() != null) {
