@@ -45,7 +45,7 @@ public class SubTabVolumeBrickView extends AbstractSubTabTableView<GlusterVolume
     public SubTabVolumeBrickView(SearchableDetailModelProvider<GlusterBrickEntity, VolumeListModel, VolumeBrickListModel> modelProvider) {
         super(modelProvider);
         initTable();
-        initWidget(getTable());
+        initWidget(getTableContainer());
     }
 
     @Override
@@ -96,34 +96,6 @@ public class SubTabVolumeBrickView extends AbstractSubTabTableView<GlusterVolume
 
         getTable().addColumn(new VolumeActivityColumn<GlusterBrickEntity>(getActivityCell()),
                 constants.activitiesOnVolume(), "100px"); //$NON-NLS-1$
-
-        getTable().addActionButton(new WebAdminButtonDefinition<GlusterBrickEntity>(constants.addBricksBrick()) {
-            @Override
-            protected UICommand resolveCommand() {
-                return getDetailModel().getAddBricksCommand();
-            }
-        });
-
-        getTable().addActionButton(new WebAdminButtonDefinition<GlusterBrickEntity>(constants.removeBricksBrick()) {
-            @Override
-            protected UICommand resolveCommand() {
-                return getDetailModel().getRemoveBricksCommand();
-            }
-        });
-
-        getTable().addActionButton(new WebAdminButtonDefinition<GlusterBrickEntity>(constants.replaceBrickBrick()) {
-            @Override
-            protected UICommand resolveCommand() {
-                return getDetailModel().getReplaceBrickCommand();
-            }
-        });
-
-        getTable().addActionButton(new WebAdminButtonDefinition<GlusterBrickEntity>(constants.advancedDetailsBrick()) {
-            @Override
-            protected UICommand resolveCommand() {
-                return getDetailModel().getBrickAdvancedDetailsCommand();
-            }
-        });
     }
 
     private VolumeActivityCompositeCell<GlusterTaskSupport> getActivityCell() {
