@@ -24,6 +24,7 @@ import org.ovirt.engine.ui.webadmin.ApplicationConstants;
 import org.ovirt.engine.ui.webadmin.ApplicationResources;
 import org.ovirt.engine.ui.webadmin.gin.AssetProvider;
 
+import com.google.gwt.dom.client.Style.Unit;
 import com.google.gwt.user.client.ui.DateLabel;
 import com.google.gwt.user.client.ui.HorizontalPanel;
 import com.google.gwt.user.client.ui.Image;
@@ -44,7 +45,7 @@ public class StoragesTree extends AbstractSubTabTree<TemplateStorageListModel, S
     protected TreeItem getRootItem(StorageDomainModel storageDomainModel) {
         HorizontalPanel panel = new HorizontalPanel();
         panel.setSpacing(1);
-        panel.setWidth("100%"); //$NON-NLS-1$
+        panel.setWidth("100%"); // $NON-NLS-1$
 
         StorageDomain storage = storageDomainModel.getStorageDomain();
 
@@ -65,7 +66,7 @@ public class StoragesTree extends AbstractSubTabTree<TemplateStorageListModel, S
     protected TreeItem getNodeItem(DiskModel diskModel) {
         HorizontalPanel panel = new HorizontalPanel();
         panel.setSpacing(1);
-        panel.setWidth("100%"); //$NON-NLS-1$
+        panel.setWidth("100%"); // $NON-NLS-1$
 
         DiskImage disk = (DiskImage) diskModel.getDisk();
 
@@ -76,7 +77,7 @@ public class StoragesTree extends AbstractSubTabTree<TemplateStorageListModel, S
         addValueLabelToPanel(panel, new EnumLabel<VolumeType>(), disk.getVolumeType(), "120px"); //$NON-NLS-1$
         addValueLabelToPanel(panel, new EnumLabel<DiskInterface>(), disk.getDiskVmElements().iterator().next().getDiskInterface(), "110px"); //$NON-NLS-1$
         addValueLabelToPanel(panel, new EnumLabel<DiskStorageType>(), disk.getDiskStorageType(), "110px"); //$NON-NLS-1$
-        addValueLabelToPanel(panel, new DateLabel(), disk.getCreationDate(), "90px"); //$NON-NLS-1$
+        addValueLabelToPanel(panel, new DateLabel(), disk.getCreationDate(), "100px"); //$NON-NLS-1$
 
         TreeItem treeItem = new TreeItem(panel);
         treeItem.setUserObject(getEntityId(diskModel));
@@ -95,11 +96,12 @@ public class StoragesTree extends AbstractSubTabTree<TemplateStorageListModel, S
         table.addColumn(new EmptyColumn(), constants.typeDisk(), "110px"); //$NON-NLS-1$
         table.addColumn(new EmptyColumn(), constants.creationDateStorageTree(), "100px"); //$NON-NLS-1$
         table.setRowData(new ArrayList());
-        table.setWidth("100%", true); //$NON-NLS-1$
+        table.setWidth("100%"); // $NON-NLS-1$
+        table.setHeight("30px"); // $NON-NLS-1$
 
         TreeItem item = new TreeItem(table);
         item.setUserObject(NODE_HEADER);
-        item.getElement().getStyle().setBackgroundColor("#F0F2FF"); //$NON-NLS-1$
+        item.getElement().getStyle().setPadding(0, Unit.PX);
         return item;
     }
 
